package com.yijia.coupon.mapper;

import java.util.List;
import com.yijia.coupon.domain.CouponInfo;

/**
 * 优惠劵Mapper接口
 * 
 * @author yijia
 * @date 2021-04-27
 */
public interface CouponInfoMapper 
{
    /**
     * 查询优惠劵
     * 
     * @param id 优惠劵ID
     * @return 优惠劵
     */
    public CouponInfo selectCouponInfoById(Integer id);

    /**
     * 查询优惠劵列表
     * 
     * @param couponInfo 优惠劵
     * @return 优惠劵集合
     */
    public List<CouponInfo> selectCouponInfoList(CouponInfo couponInfo);

    /**
     * 新增优惠劵
     * 
     * @param couponInfo 优惠劵
     * @return 结果
     */
    public int insertCouponInfo(CouponInfo couponInfo);

    /**
     * 修改优惠劵
     * 
     * @param couponInfo 优惠劵
     * @return 结果
     */
    public int updateCouponInfo(CouponInfo couponInfo);

    /**
     * 删除优惠劵
     * 
     * @param id 优惠劵ID
     * @return 结果
     */
    public int deleteCouponInfoById(Integer id);

    /**
     * 批量删除优惠劵
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCouponInfoByIds(Integer[] ids);
}
